==> ejc-techmanagement-api-3.0.0-20250418.060100-107-sources.jar: com/ejianc/business/techmanagement/vo/TecRegisterContentVO.java <==
package com.ejianc.business.techmanagement.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 新技术登记子表
 * 
 * @author generator
 * 
 */
public class TecRegisterContentVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long tecRegisterId; // 技术登记主表id
    private String code; // 单据编号
    private String tecName; // 技术名称
    private String tecType; // 技术类型
    private String applyDepartment; // 应用部门
    private String memo; // 备注

    private String reviewResult; //复核情况
    

    public Long getTecRegisterId() {
        return tecRegisterId;
    }

    public void setTecRegisterId(Long tecRegisterId) {
        this.tecRegisterId = tecRegisterId;
    }
    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public String getTecName() {
        return tecName;
    }

    public void setTecName(String tecName) {
        this.tecName = tecName;
    }
    public String getTecType() {
        return tecType;
    }

    public void setTecType(String tecType) {
        this.tecType = tecType;
    }
    public String getApplyDepartment() {
        return applyDepartment;
    }

    public void setApplyDepartment(String applyDepartment) {
        this.applyDepartment = applyDepartment;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public String getReviewResult() {
        return reviewResult;
    }

    public void setReviewResult(String reviewResult) {
        this.reviewResult = reviewResult;
    }
}

==> ejc-techmanagement-api-3.0.0-20251203.033145-123-sources.jar: com/ejianc/business/techmanagement/vo/TecRegisterContentVO.java <==
package com.ejianc.business.techmanagement.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 新技术登记子表
 * 
 * @author generator
 * 
 */
public class TecRegisterContentVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long tecRegisterId; // 技术登记主表id
    private String code; // 单据编号
    private String tecName; // 技术名称
    private String tecType; // 技术类型
    private String applyDepartment; // 应用部门
    private String memo; // 备注

    private String reviewResult; //复核情况

    @TableField(value = "apply_site_id")
    private Long applySiteId;
    @TableField(value = "apply_site_name")
    private String applySiteName;;


    @ReferSerialTransfer(referCode = "subject-project-wbs-ref")
    public Long getApplySiteId() {
        return applySiteId;
    }
    @ReferDeserialTransfer
    public void setApplySiteId(Long applySiteId) {
        this.applySiteId = applySiteId;
    }

    public String getApplySiteName() {
        return applySiteName;
    }

    public void setApplySiteName(String applySiteName) {
        this.applySiteName = applySiteName;
    }

    public Long getTecRegisterId() {
        return tecRegisterId;
    }

    public void setTecRegisterId(Long tecRegisterId) {
        this.tecRegisterId = tecRegisterId;
    }
    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public String getTecName() {
        return tecName;
    }

    public void setTecName(String tecName) {
        this.tecName = tecName;
    }
    public String getTecType() {
        return tecType;
    }

    public void setTecType(String tecType) {
        this.tecType = tecType;
    }
    public String getApplyDepartment() {
        return applyDepartment;
    }

    public void setApplyDepartment(String applyDepartment) {
        this.applyDepartment = applyDepartment;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public String getReviewResult() {
        return reviewResult;
    }

    public void setReviewResult(String reviewResult) {
        this.reviewResult = reviewResult;
    }
}
